aerosoltools.aerosol2d.Aerosol2D.timesmooth — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.timesmooth

Aerosol2D.timesmooth(window=5, method='mean', inplace=True)

  Apply rolling window smoothing to the data.

  ## Parameters

  windowint, optional

    Size of the moving window (in number of samples). Default is 5.

  methodstr, optional

    Aggregation method to use: ‘mean’, ‘median’, ‘sum’, ‘min’, or ‘max’. Default is ‘mean’.

  inplacebool, optional

    If True, modifies the current object. If False, returns a new smoothed instance. Default is True.

  ## Returns

  Aerosol1D

    Instance of Aerosol1D with smoothed data.

  Parameters:

    - window (int)

    - method (str)

    - inplace (bool)